# PoaPostData

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**vcpu_cpu_map** | [**list[PoaPostDataVcpuCpuMap]**](PoaPostDataVcpuCpuMap.md) |  | [optional] 
**node_set** | **list[str]** |  | [optional] 
**keys** | [**list[PoaPostDataKeys]**](PoaPostDataKeys.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

